# mcpgateway-client

[![Release](https://img.shields.io/github/v/release/snapby/mcpgateway-client)](https://img.shields.io/github/v/release/snapby/mcpgateway-client)
[![Build status](https://img.shields.io/github/actions/workflow/status/snapby/mcpgateway-client/main.yml?branch=main)](https://github.com/snapby/mcpgateway-client/actions/workflows/main.yml?query=branch%3Amain)
[![Commit activity](https://img.shields.io/github/commit-activity/m/snapby/mcpgateway-client)](https://img.shields.io/github/commit-activity/m/snapby/mcpgateway-client)
[![License](https://img.shields.io/github/license/snapby/mcpgateway-client)](https://img.shields.io/github/license/snapby/mcpgateway-client)

A lightweight SnapEnv McpGateway client for SnapEnv McpGateway server, enabling AI Agents access to MCP server's running on local computer.
